Structs
- Event
Group Id - SOME/IP Event Group ID (16-bit). Groups related events for subscription management.
- EventId
- SOME/IP Event ID (16-bit). By convention in the
0x8000..=0xFFFErange. - Instance
Id - Service Instance ID (16-bit). Distinguishes multiple instances of the same service on the network.
- Major
Version - Major interface version (8-bit). Incompatible changes increment this.
- Method
Id - SOME/IP Method ID (16-bit). Valid range for methods:
0x0001..=0x7FFF. The range0x8000..=0xFFFEis reserved for events. - Minor
Version - Minor interface version (32-bit). Backwards-compatible changes increment this.
- Service
Id - SOME/IP Service ID (16-bit).
- Service
Instance Id - Composite identifier for a discovered service instance on the network.